#include "ScriptComponent.h"
#include "../utils/Logging.h"
#include "../utils/ExceptionHandler.h"

ScriptComponent::ScriptComponent(Object* owner)
    : Component(owner) {}

void ScriptComponent::SetScriptPath(const std::string& path) {
    scriptPath = path;
}

const std::string& ScriptComponent::GetScriptPath() const {
    return scriptPath;
}

void ScriptComponent::Save(YAML::Emitter& out) const {
    out << YAML::BeginMap;
    out << YAML::Key << "type" << YAML::Value << "ScriptComponent";
    out << YAML::Key << "scriptPath" << YAML::Value << scriptPath;
    out << YAML::EndMap;
}

void ScriptComponent::Load(const YAML::Node& node) {
    try {
        if (!node["scriptPath"]) {
            RecoverableError("Missing 'scriptPath' in ScriptComponent", Create::Exceptions::MissingField).Handle();
            return;
        }
        if (!node["scriptPath"].IsScalar()) {
            RecoverableError("'scriptPath' must be a string", Create::Exceptions::InvalidFormat).Handle();
            return;
        }

        scriptPath = node["scriptPath"].as<std::string>();
    } catch (const YAML::Exception& e) {
        RecoverableError("Failed to load ScriptComponent: " + std::string(e.what()), Create::Exceptions::ComponentLoad).Handle();
    }
}
